@@ -39,7 +39,12 @@ from __future__ import annotations
 
 # Standard Library
 import re
-from argparse import ArgumentDefaultsHelpFormatter, BooleanOptionalAction, HelpFormatter
+from argparse import (
+    ArgumentDefaultsHelpFormatter,
+    BooleanOptionalAction,
+    HelpFormatter,
+    MetavarTypeHelpFormatter,
+)
 from dataclasses import is_dataclass
 from pydoc import locate
 
@@ -57,7 +62,13 @@ A = TypeVar("A")
 B = TypeVar("B")
 
 try:
-    from rich_argparse import RichHelpFormatter as Formatter
+    from rich_argparse import RichHelpFormatter
+
+    class Formatter(
+        RichHelpFormatter, ArgumentDefaultsHelpFormatter, MetavarTypeHelpFormatter
+    ):
+        pass
+
 except ImportError:
     Formatter = ArgumentDefaultsHelpFormatter  # type: ignore
 
@@ -65,7 +76,7 @@ except ImportError:
 def from_dataclass(
     config: DC,
     *,
-    formatter: HelpFormatter = Formatter,  # type: ignore
+    formatter: Formatter | HelpFormatter = Formatter,  # type: ignore
     ns: Union[dict[str, Any], None] = None,
 ) -> Config:
     """Build config from dataclass."""
